"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.group = void 0;
const testCollector_1 = require("../common/testCollector");
const utils_1 = require("../utils");
/**
 * Create a group of tests.
 *
 * @param descriptionDefinition Resolvable description of the group. It is often a string,
 * but can be sync or async functions, numbers, booleans... Functions will be executed to get the
 * primitive value of then.
 *
 * @param testDefinitions Function for Corde to invoke that will define inner suites a test
 *
 * @since 1.0
 */
const group = (definitionResolvable, testDefinitions) => {
    const _internalGroup = async () => {
        testCollector_1.testCollector.isInsideGroupClausure = true;
        if (testDefinitions) {
            await testDefinitions();
            await testCollector_1.testCollector.executeTestClojure();
            const resolvedName = await (0, utils_1.resolveName)(definitionResolvable);
            // In case of expect() be added in test closure
            // that is contained in testDefinitions()
            if (testCollector_1.testCollector.tests && testCollector_1.testCollector.tests.length > 0) {
                testCollector_1.testCollector.groups.push({
                    name: resolvedName,
                    tests: testCollector_1.testCollector.tests.map((test) => test),
                });
            }
            // Case expect() be added inside the group closure
            if (testCollector_1.testCollector.isInsideTestClausureFunctions()) {
                const testsCloned = testCollector_1.testCollector.cloneTestFunctions();
                testCollector_1.testCollector.groups.push({
                    name: resolvedName,
                    tests: [{ testsFunctions: testsCloned }],
                });
                testCollector_1.testCollector.clearTestFunctions();
            }
        }
        testCollector_1.testCollector.tests = [];
        testCollector_1.testCollector.isInsideGroupClausure = false;
    };
    testCollector_1.testCollector.addToGroupClousure(async () => await _internalGroup());
};
exports.group = group;
