"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.test = void 0;
const testCollector_1 = require("../common/testCollector");
const utils_1 = require("../utils");
/**
 * Define a single test. A test should contain one or more expectations that test action of
 * the discord bot.
 * A spec whose expectations all succeed will be passing and a spec with any failures will fail.
 *
 * @param expectationDescription Textual description of what this test is checking
 * @param assertion Function that contains the code of your test. If not provided it will be ignored in the report.
 * @param timeout Custom timeout for an async test
 *
 * @since 1.0
 */
const test = (expectationDescription, assertion, timeout) => {
    const _internalTest = async () => {
        testCollector_1.testCollector.isInsideTestClausure = true;
        if (assertion) {
            await assertion();
            const testName = await (0, utils_1.resolveName)(expectationDescription);
            if (testCollector_1.testCollector.testsFunctions && testCollector_1.testCollector.testsFunctions.length) {
                testCollector_1.testCollector.tests.push({
                    name: testName,
                    testsFunctions: testCollector_1.testCollector.cloneTestFunctions(),
                });
            }
        }
        testCollector_1.testCollector.testsFunctions = [];
        testCollector_1.testCollector.isInsideTestClausure = false;
    };
    if (timeout) {
        testCollector_1.testCollector.addToGroupClousure(async () => {
            await (0, utils_1.executePromiseWithTimeout)(async (resolve) => {
                await _internalTest();
                resolve();
            }, timeout);
        });
    }
    else {
        testCollector_1.testCollector.addToTestClousure(async () => await _internalTest());
    }
};
exports.test = test;
