"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.afterEach = void 0;
const testCollector_1 = require("../common/testCollector");
const utils_1 = require("../utils");
const hookBuilder_1 = require("./hookBuilder");
/**
 * Declare a bunch of code that will be executed **after each** test.
 *
 * More than one declaration of this code results in a list
 * of functions to run, following a sequence of files
 * reads and the positions of each `afterEach` call.
 *
 * @param fn code that will be executed **after each** tests finish
 * @param timeout Time that Corde should wait for the execution of this function.
 * **it overrides the timeout defined in configs**.
 *
 * @since 2.0
 */
function afterEach(fn, timeout) {
    if (typeof fn === "function") {
        const trace = (0, utils_1.getStackTrace)();
        (0, hookBuilder_1.hookBuilder)({
            queueToAdd: testCollector_1.testCollector.afterEachFunctions,
            fn,
            trace,
            errorTitle: "AfterEachError",
            timeout,
        });
    }
}
exports.afterEach = afterEach;
