"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.permissionsArray = exports.Permission = exports.Colors = exports.ColorsHex = exports.SystemChannelFlag = exports.GuildFeatures = exports.VerificationLevel = void 0;
/**
 * @see https://discord.com/developers/docs/resources/guild#guild-object-verification-level
 */
var VerificationLevel;
(function (VerificationLevel) {
    /**
     * Unrestricted
     */
    VerificationLevel["NONE"] = "NONE";
    /**
     * Must have verified email on account
     */
    VerificationLevel["LOW"] = "LOW";
    /**
     * Must be registered on Discord for longer than 5 minutes
     */
    VerificationLevel["MEDIUM"] = "MEDIUM";
    /**
     * Must be a member of the server for longer than 10 minutes
     */
    VerificationLevel["HIGH"] = "HIGH";
    /**
     * Must have a verified phone number
     */
    VerificationLevel["VERY_HIGH"] = "VERY_HIGH";
})(VerificationLevel = exports.VerificationLevel || (exports.VerificationLevel = {}));
/**
 * Defines Guild's features
 *
 * @see https://discord.com/developers/docs/resources/guild#guild-object-guild-features
 */
var GuildFeatures;
(function (GuildFeatures) {
    /**
     * Guild has access to set an invite splash background
     */
    GuildFeatures["INVITE_SPLASH"] = "INVITE_SPLASH";
    /**
     * Guild has access to set 384kbps bitrate in voice (previously VIP voice servers)
     */
    GuildFeatures["VIP_REGIONS"] = "VIP_REGIONS";
    /**
     * Guild has access to set a vanity URL
     */
    GuildFeatures["VANITY_URL"] = "VANITY_URL";
    /**
     * Guild is verified
     */
    GuildFeatures["VERIFIED"] = "VERIFIED";
    /**
     * Guild is partnered
     */
    GuildFeatures["PARTNERED"] = "PARTNERED";
    /**
     * Guild can enable welcome screen, Membership Screening, and discovery, and receives community updates
     */
    GuildFeatures["COMMUNITY"] = "COMMUNITY";
    /**
     * Guild has access to use commerce features (i.e. create store channels)
     */
    GuildFeatures["COMMERCE"] = "COMMERCE";
    /**
     * Guild has access to create news channels
     */
    GuildFeatures["NEWS"] = "NEWS";
    /**
     * Guild can be discovered in the directory
     */
    GuildFeatures["DISCOVERABLE"] = "DISCOVERABLE";
    /**
     * Guild can be featured in the directory
     */
    GuildFeatures["FEATURABLE"] = "FEATURABLE";
    /**
     * Guild has access to set an animated guild icon
     */
    GuildFeatures["ANIMATED_ICON"] = "ANIMATED_ICON";
    /**
     * Guild has access to set a guild banner image
     */
    GuildFeatures["BANNER"] = "BANNER";
    /**
     * Guild has enabled the welcome screen
     */
    GuildFeatures["WELCOME_SCREEN_ENABLED"] = "WELCOME_SCREEN_ENABLED";
    /**
     * Guild has enabled [Membership Screening](https://discord.com/developers/docs/resources/guild#membership-screening-object)
     */
    GuildFeatures["MEMBER_VERIFICATION_GATE_ENABLED"] = "MEMBER_VERIFICATION_GATE_ENABLED";
    /**
     * Guild can be previewed before joining via Membership Screening or the directory
     */
    GuildFeatures["PREVIEW_ENABLED"] = "PREVIEW_ENABLED";
})(GuildFeatures = exports.GuildFeatures || (exports.GuildFeatures = {}));
/**
 * System channel flags of Discord
 *
 * @see https://discord.com/developers/docs/resources/guild#guild-object-system-channel-flags
 */
var SystemChannelFlag;
(function (SystemChannelFlag) {
    /**
     * Suppress member join notifications
     */
    SystemChannelFlag["SUPPRESS_JOIN_NOTIFICATIONS"] = "SUPPRESS_JOIN_NOTIFICATIONS";
    /**
     * Suppress server boost notifications
     */
    SystemChannelFlag["SUPPRESS_PREMIUM_SUBSCRIPTIONS"] = "SUPPRESS_PREMIUM_SUBSCRIPTIONS";
})(SystemChannelFlag = exports.SystemChannelFlag || (exports.SystemChannelFlag = {}));
var ColorsHex;
(function (ColorsHex) {
    ColorsHex[ColorsHex["DEFAULT"] = 0] = "DEFAULT";
    ColorsHex[ColorsHex["WHITE"] = 16777215] = "WHITE";
    ColorsHex[ColorsHex["AQUA"] = 1752220] = "AQUA";
    ColorsHex[ColorsHex["GREEN"] = 3066993] = "GREEN";
    ColorsHex[ColorsHex["BLUE"] = 3447003] = "BLUE";
    ColorsHex[ColorsHex["YELLOW"] = 16776960] = "YELLOW";
    ColorsHex[ColorsHex["PURPLE"] = 10181046] = "PURPLE";
    ColorsHex[ColorsHex["LUMINOUS_VIVID_PINK"] = 15277667] = "LUMINOUS_VIVID_PINK";
    ColorsHex[ColorsHex["GOLD"] = 15844367] = "GOLD";
    ColorsHex[ColorsHex["ORANGE"] = 15105570] = "ORANGE";
    ColorsHex[ColorsHex["RED"] = 15158332] = "RED";
    ColorsHex[ColorsHex["GREY"] = 9807270] = "GREY";
    ColorsHex[ColorsHex["NAVY"] = 3426654] = "NAVY";
    ColorsHex[ColorsHex["DARK_AQUA"] = 1146986] = "DARK_AQUA";
    ColorsHex[ColorsHex["DARK_GREEN"] = 2067276] = "DARK_GREEN";
    ColorsHex[ColorsHex["DARK_BLUE"] = 2123412] = "DARK_BLUE";
    ColorsHex[ColorsHex["DARK_PURPLE"] = 7419530] = "DARK_PURPLE";
    ColorsHex[ColorsHex["DARK_VIVID_PINK"] = 11342935] = "DARK_VIVID_PINK";
    ColorsHex[ColorsHex["DARK_GOLD"] = 12745742] = "DARK_GOLD";
    ColorsHex[ColorsHex["DARK_ORANGE"] = 11027200] = "DARK_ORANGE";
    ColorsHex[ColorsHex["DARK_RED"] = 10038562] = "DARK_RED";
    ColorsHex[ColorsHex["DARK_GREY"] = 9936031] = "DARK_GREY";
    ColorsHex[ColorsHex["DARKER_GREY"] = 8359053] = "DARKER_GREY";
    ColorsHex[ColorsHex["LIGHT_GREY"] = 12370112] = "LIGHT_GREY";
    ColorsHex[ColorsHex["DARK_NAVY"] = 2899536] = "DARK_NAVY";
    ColorsHex[ColorsHex["BLURPLE"] = 7506394] = "BLURPLE";
    ColorsHex[ColorsHex["GREYPLE"] = 10070709] = "GREYPLE";
    ColorsHex[ColorsHex["DARK_BUT_NOT_BLACK"] = 2895667] = "DARK_BUT_NOT_BLACK";
    ColorsHex[ColorsHex["NOT_QUITE_BLACK"] = 2303786] = "NOT_QUITE_BLACK";
})(ColorsHex = exports.ColorsHex || (exports.ColorsHex = {}));
var Colors;
(function (Colors) {
    Colors["DEFAULT"] = "#000000";
    Colors["WHITE"] = "#FFFFFF";
    Colors["AQUA"] = "#1ABC9C";
    Colors["GREEN"] = "#2ECC71";
    Colors["BLUE"] = "#3498DB";
    Colors["PURPLE"] = "#9B59B6";
    Colors["GOLD"] = "#E91E63";
    Colors["ORANGE"] = "#E67E22";
    Colors["RED"] = "#E74C3C";
    Colors["GREY"] = "#95A5A6";
    Colors["DARKER_GREY"] = "#7F8C8D";
    Colors["NAVY"] = "#34495E";
    Colors["DARK_AQUA"] = "#11806A";
    Colors["DARK_GREEN"] = "#1F8B4C";
    Colors["DARK_BLUE"] = "#206694";
    Colors["DARK_PURPLE"] = "#71368A";
    Colors["DARK_GOLD"] = "#C27C0E";
    Colors["DARK_ORANGE"] = "#A84300";
    Colors["DARK_RED"] = "#992D22";
    Colors["DARK_GREY"] = "#7F8C8D";
    Colors["LIGHT_GREY"] = "#BCC0C0";
    Colors["DARK_NAVY"] = "#2C3E50";
    Colors["LUMINOUS_VIVID_PINK"] = "#E91E63";
    Colors["DARK_VIVID_PINK"] = "#AD1457";
})(Colors = exports.Colors || (exports.Colors = {}));
/**
 * Enum with of all current permissions of Discord, their integer values in hexadecimal.
 *
 * https://discord.com/developers/docs/topics/permissions#permissions-bitwise-permission-flags
 */
var Permission;
(function (Permission) {
    /**
     * Allows creation of instant invites
     * @summary For **Text** and **Voice** Channel
     */
    Permission[Permission["CREATE_INSTANT_INVITE"] = 1] = "CREATE_INSTANT_INVITE";
    /**
     * Allows kicking members
     * @summary Indifferent of channel
     */
    Permission[Permission["KICK_MEMBERS"] = 2] = "KICK_MEMBERS";
    /**
     * Allows banning members
     * @summary Indifferent of channel
     */
    Permission[Permission["BAN_MEMBERS"] = 4] = "BAN_MEMBERS";
    /**
     * Allows all permissions and bypasses channel permission overwrites.
     * @summary Indifferent of channel
     */
    Permission[Permission["ADMINISTRATOR"] = 8] = "ADMINISTRATOR";
    /**
     * Allows management and editing of channels
     * @summary For **Text** and **Voice** Channel
     */
    Permission[Permission["MANAGE_CHANNELS"] = 16] = "MANAGE_CHANNELS";
    /**
     * Allows management and editing of the guild
     * @summary For **Text** and **Voice** Channel
     */
    Permission[Permission["MANAGE_GUILD"] = 32] = "MANAGE_GUILD";
    /**
     * Allows for the addition of reactions to messages
     * @summary For **Text** Channel only
     */
    Permission[Permission["ADD_REACTIONS"] = 64] = "ADD_REACTIONS";
    /**
     * Allows for viewing of audit logs
     * @summary For **Text** and **Voice** Channel
     */
    Permission[Permission["VIEW_AUDIT_LOG"] = 128] = "VIEW_AUDIT_LOG";
    /**
     * Allows guild members to view a channel, which includes reading messages in text channels
     * @summary Indifferent of channel
     */
    Permission[Permission["VIEW_CHANNEL"] = 1024] = "VIEW_CHANNEL";
    /**
     * Allows for sending messages in a channel
     * @summary For **Text** Channel only
     */
    Permission[Permission["SEND_MESSAGES"] = 2048] = "SEND_MESSAGES";
    /**
     * Allows for sending of /tts messages
     * @summary For **Text** Channel only
     */
    Permission[Permission["SEND_TTS_MESSAGES"] = 4096] = "SEND_TTS_MESSAGES";
    /**
     * Allows for deletion of other users messages
     * @summary For **Text** Channel only
     */
    Permission[Permission["MANAGE_MESSAGES"] = 8192] = "MANAGE_MESSAGES";
    /**
     * Links sent by users with this permission will be auto-embedded
     * @summary For **Text** Channel only
     */
    Permission[Permission["EMBED_LINKS"] = 16384] = "EMBED_LINKS";
    /**
     * Allows for uploading images and files
     * @summary For **Text** Channel only
     */
    Permission[Permission["ATTACH_FILES"] = 32768] = "ATTACH_FILES";
    /**
     * Allows for reading of message history
     * @summary For **Text** Channel only
     */
    Permission[Permission["READ_MESSAGE_HISTORY"] = 65536] = "READ_MESSAGE_HISTORY";
    /**
     * Allows for using the @everyone tag to notify all users in a channel,
     * and the @here tag to notify all online users in a channel
     * @summary For **Text** Channel only
     */
    Permission[Permission["MENTION_EVERYONE"] = 131072] = "MENTION_EVERYONE";
    /**
     * Allows the usage of custom emojis from other servers
     * @summary For **Text** Channel only
     */
    Permission[Permission["USE_EXTERNAL_EMOJIS"] = 262144] = "USE_EXTERNAL_EMOJIS";
    /**
     * Allows for joining of a voice channel
     * @summary For **Voice** Channel only
     */
    Permission[Permission["CONNECT"] = 1048576] = "CONNECT";
    /**
     * Allows for speaking in a voice channel
     * @summary For **Voice** Channel only
     */
    Permission[Permission["SPEAK"] = 2097152] = "SPEAK";
    /**
     * Allows for muting members in a voice channel
     * @summary For **Voice** Channel only
     */
    Permission[Permission["MUTE_MEMBERS"] = 4194304] = "MUTE_MEMBERS";
    /**
     * Allows for deafening of members in a voice channel
     * @summary For **Voice** Channel only
     */
    Permission[Permission["DEAFEN_MEMBERS"] = 8388608] = "DEAFEN_MEMBERS";
    /**
     * Allows for moving of members between voice channels
     * @summary For **Voice** Channel only
     */
    Permission[Permission["MOVE_MEMBERS"] = 16777216] = "MOVE_MEMBERS";
    /**
     * Allows for using voice-activity-detection in a voice channel
     * @summary For **Voice** Channel only
     */
    Permission[Permission["USE_VAD"] = 33554432] = "USE_VAD";
    /**
     * Allows for using priority speaker in a voice channel
     * @summary For **Voice** Channel only
     */
    Permission[Permission["PRIORITY_SPEAKER"] = 256] = "PRIORITY_SPEAKER";
    /**
     * Allows for modification of own nickname
     * @summary Indifferent of channel
     */
    Permission[Permission["CHANGE_NICKNAME"] = 67108864] = "CHANGE_NICKNAME";
    /**
     * Allows for modification of other users nicknames
     * @summary Indifferent of channel
     */
    Permission[Permission["MANAGE_NICKNAMES"] = 134217728] = "MANAGE_NICKNAMES";
    /**
     * Allows management and editing of roles
     * @summary For **Text** and **Voice** Channel
     */
    Permission[Permission["MANAGE_ROLES"] = 268435456] = "MANAGE_ROLES";
    /**
     * Allows management and editing of webhooks
     * @summary For **Text** and **Voice** Channel
     */
    Permission[Permission["MANAGE_WEBHOOKS"] = 536870912] = "MANAGE_WEBHOOKS";
    /**
     * Allows management and editing of emojis
     * @summary Indifferent of channel
     */
    Permission[Permission["MANAGE_EMOJIS"] = 1073741824] = "MANAGE_EMOJIS";
    /**
     * Allows the user to go live
     * @summary For **Voice** Channel only
     */
    Permission[Permission["STREAM"] = 512] = "STREAM";
    /**
     * Allows for viewing guild insights
     * @summary Indifferent of channel
     */
    Permission[Permission["VIEW_GUILD_INSIGHTS"] = 524288] = "VIEW_GUILD_INSIGHTS";
})(Permission = exports.Permission || (exports.Permission = {}));
const permissionsArray = Object.keys(Permission);
exports.permissionsArray = permissionsArray;
