"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.executeWithTimeout = void 0;
const utils_1 = require("./utils");
/**
 * Executes a function with a timeout.
 * If the function takes more time to run than what was provided in
 * `timeout`, then this functions is rejected.
 *
 * @param fn Function to be executed.
 * @param timeout Time that this function will wait.
 * @returns Result of the executed function (`fn`)
 * @internal
 */
async function executeWithTimeout(fn, timeout) {
    if (!fn) {
        throw new Error("can not execute an null function");
    }
    if (utils_1.utils.isInDebugMode()) {
        return await fn();
    }
    const nodeTimeout = setTimeout(() => {
        throw new Error("timeout");
    }, timeout);
    const response = await fn();
    clearTimeout(nodeTimeout);
    return response;
}
exports.executeWithTimeout = executeWithTimeout;
